CDAdController class
Constructors
Properties
- geoInfo ↔ CDGeoInfo?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAdAutoRefreshEnabled ↔ bool
-
getter/setter pair
- isCloseable ↔ bool
-
getter/setter pair
- isLocationAutoUpdateEnabled ↔ bool
-
getter/setter pair
- isTesting ↔ bool
-
getter/setter pair
- partnerId ↔ String?
-
getter/setter pair
- placementId ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useInappBrowser ↔ bool
-
getter/setter pair
Methods
-
bindChannel(
MethodChannel channel) → void -
loadAd(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited