CDGeoInfo class

Constructors

CDGeoInfo({required double lat, required double lon, required String countryCode, required String region, required String city, required String zip, String streetAddress = '', String subThoroughFare = '', String haccuracy = "5"})

Properties

city → String
final
countryCode → String
final
haccuracy → String
final
hashCode → int
The hash code for this object.
no setterinherited
lat → double
final
lon → double
final
region → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetAddress → String
final
subThoroughFare → String
final
type → int
final
zip → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited